# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/circle.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/circle.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17iotics/api/circle.proto\x12\niotics.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17iotics/api/common.proto\"\x1a\n\x08\x43ircleID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xfa\x01\n\x13UpsertCircleRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.UpsertCircleRequest.PayloadR\x07payload\x1aq\n\x07Payload\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\x12\x34\n\nproperties\x18\x02 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\"\xc6\x01\n\x14UpsertCircleResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.UpsertCircleResponse.PayloadR\x07payload\x1a;\n\x07Payload\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\"\xc2\x01\n\x13\x44\x65leteCircleRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12=\n\x04\x61rgs\x18\x02 \x01(\x0b\x32).iotics.api.DeleteCircleRequest.ArgumentsR\x04\x61rgs\x1a=\n\tArguments\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\"\xc6\x01\n\x14\x44\x65leteCircleResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.DeleteCircleResponse.PayloadR\x07payload\x1a;\n\x07Payload\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\"\xc6\x01\n\x15\x44\x65scribeCircleRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x04\x61rgs\x18\x03 \x01(\x0b\x32+.iotics.api.DescribeCircleRequest.ArgumentsR\x04\x61rgs\x1a=\n\tArguments\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\"\x90\x03\n\x16\x44\x65scribeCircleResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x44\n\x07payload\x18\x02 \x01(\x0b\x32*.iotics.api.DescribeCircleResponse.PayloadR\x07payload\x1a|\n\nMetaResult\x12\x34\n\nproperties\x18\x01 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1a\x82\x01\n\x07Payload\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\x12\x45\n\x06result\x18\x02 \x01(\x0b\x32-.iotics.api.DescribeCircleResponse.MetaResultR\x06result\"o\n\x15ListAllCirclesRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05range\x18\x14 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\"\x98\x03\n\x16ListAllCirclesResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x44\n\x07payload\x18\x02 \x01(\x0b\x32*.iotics.api.ListAllCirclesResponse.PayloadR\x07payload\x1a\xb1\x01\n\rCircleDetails\x12\x30\n\x08\x63ircleId\x18\x01 \x01(\x0b\x32\x14.iotics.api.CircleIDR\x08\x63ircleId\x12\x34\n\nproperties\x18\x02 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1aU\n\x07Payload\x12J\n\x07\x63ircles\x18\x01 \x03(\x0b\x32\x30.iotics.api.ListAllCirclesResponse.CircleDetailsR\x07\x63ircles2\xeb\x02\n\tCircleAPI\x12S\n\x0cUpsertCircle\x12\x1f.iotics.api.UpsertCircleRequest\x1a .iotics.api.UpsertCircleResponse\"\x00\x12S\n\x0c\x44\x65leteCircle\x12\x1f.iotics.api.DeleteCircleRequest\x1a .iotics.api.DeleteCircleResponse\"\x00\x12Y\n\x0e\x44\x65scribeCircle\x12!.iotics.api.DescribeCircleRequest\x1a\".iotics.api.DescribeCircleResponse\"\x00\x12Y\n\x0eListAllCircles\x12!.iotics.api.ListAllCirclesRequest\x1a\".iotics.api.ListAllCirclesResponse\"\x00\x42\x7f\n\x0e\x63om.iotics.apiB\x0b\x43ircleProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.circle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\013CircleProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_CIRCLEID']._serialized_start=97
  _globals['_CIRCLEID']._serialized_end=123
  _globals['_UPSERTCIRCLEREQUEST']._serialized_start=126
  _globals['_UPSERTCIRCLEREQUEST']._serialized_end=376
  _globals['_UPSERTCIRCLEREQUEST_PAYLOAD']._serialized_start=263
  _globals['_UPSERTCIRCLEREQUEST_PAYLOAD']._serialized_end=376
  _globals['_UPSERTCIRCLERESPONSE']._serialized_start=379
  _globals['_UPSERTCIRCLERESPONSE']._serialized_end=577
  _globals['_UPSERTCIRCLERESPONSE_PAYLOAD']._serialized_start=263
  _globals['_UPSERTCIRCLERESPONSE_PAYLOAD']._serialized_end=322
  _globals['_DELETECIRCLEREQUEST']._serialized_start=580
  _globals['_DELETECIRCLEREQUEST']._serialized_end=774
  _globals['_DELETECIRCLEREQUEST_ARGUMENTS']._serialized_start=713
  _globals['_DELETECIRCLEREQUEST_ARGUMENTS']._serialized_end=774
  _globals['_DELETECIRCLERESPONSE']._serialized_start=777
  _globals['_DELETECIRCLERESPONSE']._serialized_end=975
  _globals['_DELETECIRCLERESPONSE_PAYLOAD']._serialized_start=263
  _globals['_DELETECIRCLERESPONSE_PAYLOAD']._serialized_end=322
  _globals['_DESCRIBECIRCLEREQUEST']._serialized_start=978
  _globals['_DESCRIBECIRCLEREQUEST']._serialized_end=1176
  _globals['_DESCRIBECIRCLEREQUEST_ARGUMENTS']._serialized_start=713
  _globals['_DESCRIBECIRCLEREQUEST_ARGUMENTS']._serialized_end=774
  _globals['_DESCRIBECIRCLERESPONSE']._serialized_start=1179
  _globals['_DESCRIBECIRCLERESPONSE']._serialized_end=1579
  _globals['_DESCRIBECIRCLERESPONSE_METARESULT']._serialized_start=1322
  _globals['_DESCRIBECIRCLERESPONSE_METARESULT']._serialized_end=1446
  _globals['_DESCRIBECIRCLERESPONSE_PAYLOAD']._serialized_start=1449
  _globals['_DESCRIBECIRCLERESPONSE_PAYLOAD']._serialized_end=1579
  _globals['_LISTALLCIRCLESREQUEST']._serialized_start=1581
  _globals['_LISTALLCIRCLESREQUEST']._serialized_end=1692
  _globals['_LISTALLCIRCLESRESPONSE']._serialized_start=1695
  _globals['_LISTALLCIRCLESRESPONSE']._serialized_end=2103
  _globals['_LISTALLCIRCLESRESPONSE_CIRCLEDETAILS']._serialized_start=1839
  _globals['_LISTALLCIRCLESRESPONSE_CIRCLEDETAILS']._serialized_end=2016
  _globals['_LISTALLCIRCLESRESPONSE_PAYLOAD']._serialized_start=2018
  _globals['_LISTALLCIRCLESRESPONSE_PAYLOAD']._serialized_end=2103
  _globals['_CIRCLEAPI']._serialized_start=2106
  _globals['_CIRCLEAPI']._serialized_end=2469
# @@protoc_insertion_point(module_scope)
