# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/meta.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/meta.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15iotics/api/meta.proto\x12\niotics.api\x1a\x17google/rpc/status.proto\x1a\x17iotics/api/common.proto\"\x9b\x02\n\x12SparqlQueryRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05scope\x18\x02 \x01(\x0e\x32\x11.iotics.api.ScopeR\x05scope\x12@\n\x07payload\x18\x03 \x01(\x0b\x32&.iotics.api.SparqlQueryRequest.PayloadR\x07payload\x1ak\n\x07Payload\x12J\n\x11resultContentType\x18\x01 \x01(\x0e\x32\x1c.iotics.api.SparqlResultTypeR\x11resultContentType\x12\x14\n\x05query\x18\x02 \x01(\x0cR\x05query\"\xcd\x02\n\x13SparqlQueryResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.SparqlQueryResponse.PayloadR\x07payload\x1a\xc3\x01\n\x07Payload\x12\x16\n\x06seqNum\x18\x01 \x01(\x04R\x06seqNum\x12\x12\n\x04last\x18\x02 \x01(\x08R\x04last\x12*\n\x06status\x18\x03 \x01(\x0b\x32\x12.google.rpc.StatusR\x06status\x12>\n\x0b\x63ontentType\x18\x04 \x01(\x0e\x32\x1c.iotics.api.SparqlResultTypeR\x0b\x63ontentType\x12 \n\x0bresultChunk\x18\x05 \x01(\x0cR\x0bresultChunk\"\xaa\x01\n\x13SparqlUpdateRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.SparqlUpdateRequest.PayloadR\x07payload\x1a!\n\x07Payload\x12\x16\n\x06update\x18\x01 \x01(\x0cR\x06update\"E\n\x14SparqlUpdateResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers*r\n\x10SparqlResultType\x12\x0f\n\x0bSPARQL_JSON\x10\x00\x12\x0e\n\nSPARQL_XML\x10\x01\x12\x0e\n\nSPARQL_CSV\x10\x02\x12\x0e\n\nRDF_TURTLE\x10\x03\x12\x0b\n\x07RDF_XML\x10\x04\x12\x10\n\x0cRDF_NTRIPLES\x10\x05\x32\xb2\x01\n\x07MetaAPI\x12R\n\x0bSparqlQuery\x12\x1e.iotics.api.SparqlQueryRequest\x1a\x1f.iotics.api.SparqlQueryResponse\"\x00\x30\x01\x12S\n\x0cSparqlUpdate\x12\x1f.iotics.api.SparqlUpdateRequest\x1a .iotics.api.SparqlUpdateResponse\"\x00\x42}\n\x0e\x63om.iotics.apiB\tMetaProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.meta_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\tMetaProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_SPARQLRESULTTYPE']._serialized_start=953
  _globals['_SPARQLRESULTTYPE']._serialized_end=1067
  _globals['_SPARQLQUERYREQUEST']._serialized_start=88
  _globals['_SPARQLQUERYREQUEST']._serialized_end=371
  _globals['_SPARQLQUERYREQUEST_PAYLOAD']._serialized_start=264
  _globals['_SPARQLQUERYREQUEST_PAYLOAD']._serialized_end=371
  _globals['_SPARQLQUERYRESPONSE']._serialized_start=374
  _globals['_SPARQLQUERYRESPONSE']._serialized_end=707
  _globals['_SPARQLQUERYRESPONSE_PAYLOAD']._serialized_start=512
  _globals['_SPARQLQUERYRESPONSE_PAYLOAD']._serialized_end=707
  _globals['_SPARQLUPDATEREQUEST']._serialized_start=710
  _globals['_SPARQLUPDATEREQUEST']._serialized_end=880
  _globals['_SPARQLUPDATEREQUEST_PAYLOAD']._serialized_start=847
  _globals['_SPARQLUPDATEREQUEST_PAYLOAD']._serialized_end=880
  _globals['_SPARQLUPDATERESPONSE']._serialized_start=882
  _globals['_SPARQLUPDATERESPONSE']._serialized_end=951
  _globals['_METAAPI']._serialized_start=1070
  _globals['_METAAPI']._serialized_end=1248
# @@protoc_insertion_point(module_scope)
