# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/interest.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/interest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2
from iotics.api import feed_pb2 as iotics_dot_api_dot_feed__pb2
from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19iotics/api/interest.proto\x12\niotics.api\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17iotics/api/common.proto\x1a\x15iotics/api/feed.proto\x1a\x16iotics/api/input.proto\"~\n\rInputInterest\x12\x36\n\x0csenderTwinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x0csenderTwinId\x12\x35\n\x0b\x64\x65stInputId\x18\x02 \x01(\x0b\x32\x13.iotics.api.InputIDR\x0b\x64\x65stInputId\"\xd5\x02\n\x17SendInputMessageRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x04\x61rgs\x18\x02 \x01(\x0b\x32-.iotics.api.SendInputMessageRequest.ArgumentsR\x04\x61rgs\x12\x45\n\x07payload\x18\x03 \x01(\x0b\x32+.iotics.api.SendInputMessageRequest.PayloadR\x07payload\x1a=\n\x07Payload\x12\x32\n\x07message\x18\x01 \x01(\x0b\x32\x18.iotics.api.InputMessageR\x07message\x1a\x42\n\tArguments\x12\x35\n\x08interest\x18\x01 \x01(\x0b\x32\x19.iotics.api.InputInterestR\x08interest\"I\n\x18SendInputMessageResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\"\x82\x01\n\x08Interest\x12:\n\x0e\x66ollowerTwinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x0e\x66ollowerTwinId\x12:\n\x0e\x66ollowedFeedId\x18\x02 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x0e\x66ollowedFeedId\"\x8a\x02\n\x14\x46\x65tchInterestRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12>\n\x04\x61rgs\x18\x02 \x01(\x0b\x32*.iotics.api.FetchInterestRequest.ArgumentsR\x04\x61rgs\x12\x44\n\x0f\x66\x65tchLastStored\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0f\x66\x65tchLastStored\x1a=\n\tArguments\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest\"\xfa\x01\n\x15\x46\x65tchInterestResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x43\n\x07payload\x18\x02 \x01(\x0b\x32).iotics.api.FetchInterestResponse.PayloadR\x07payload\x1am\n\x07Payload\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest\x12\x30\n\x08\x66\x65\x65\x64\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.iotics.api.FeedDataR\x08\x66\x65\x65\x64\x44\x61ta\"\xc8\x01\n\x16\x46\x65tchLastStoredRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x04\x61rgs\x18\x02 \x01(\x0b\x32,.iotics.api.FetchLastStoredRequest.ArgumentsR\x04\x61rgs\x1a=\n\tArguments\x12\x30\n\x08interest\x18\x01 \x01(\x0b\x32\x14.iotics.api.InterestR\x08interest2\xa5\x02\n\x0bInterestAPI\x12Y\n\x0e\x46\x65tchInterests\x12 .iotics.api.FetchInterestRequest\x1a!.iotics.api.FetchInterestResponse\"\x00\x30\x01\x12Z\n\x0f\x46\x65tchLastStored\x12\".iotics.api.FetchLastStoredRequest\x1a!.iotics.api.FetchInterestResponse\"\x00\x12_\n\x10SendInputMessage\x12#.iotics.api.SendInputMessageRequest\x1a$.iotics.api.SendInputMessageResponse\"\x00\x42\x81\x01\n\x0e\x63om.iotics.apiB\rInterestProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.interest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\rInterestProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_INPUTINTEREST']._serialized_start=145
  _globals['_INPUTINTEREST']._serialized_end=271
  _globals['_SENDINPUTMESSAGEREQUEST']._serialized_start=274
  _globals['_SENDINPUTMESSAGEREQUEST']._serialized_end=615
  _globals['_SENDINPUTMESSAGEREQUEST_PAYLOAD']._serialized_start=486
  _globals['_SENDINPUTMESSAGEREQUEST_PAYLOAD']._serialized_end=547
  _globals['_SENDINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_start=549
  _globals['_SENDINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_end=615
  _globals['_SENDINPUTMESSAGERESPONSE']._serialized_start=617
  _globals['_SENDINPUTMESSAGERESPONSE']._serialized_end=690
  _globals['_INTEREST']._serialized_start=693
  _globals['_INTEREST']._serialized_end=823
  _globals['_FETCHINTERESTREQUEST']._serialized_start=826
  _globals['_FETCHINTERESTREQUEST']._serialized_end=1092
  _globals['_FETCHINTERESTREQUEST_ARGUMENTS']._serialized_start=1031
  _globals['_FETCHINTERESTREQUEST_ARGUMENTS']._serialized_end=1092
  _globals['_FETCHINTERESTRESPONSE']._serialized_start=1095
  _globals['_FETCHINTERESTRESPONSE']._serialized_end=1345
  _globals['_FETCHINTERESTRESPONSE_PAYLOAD']._serialized_start=1236
  _globals['_FETCHINTERESTRESPONSE_PAYLOAD']._serialized_end=1345
  _globals['_FETCHLASTSTOREDREQUEST']._serialized_start=1348
  _globals['_FETCHLASTSTOREDREQUEST']._serialized_end=1548
  _globals['_FETCHLASTSTOREDREQUEST_ARGUMENTS']._serialized_start=1031
  _globals['_FETCHLASTSTOREDREQUEST_ARGUMENTS']._serialized_end=1092
  _globals['_INTERESTAPI']._serialized_start=1551
  _globals['_INTERESTAPI']._serialized_end=1844
# @@protoc_insertion_point(module_scope)
