# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/input.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/input.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16iotics/api/input.proto\x12\niotics.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17iotics/api/common.proto\"I\n\x07InputID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06twinId\x18\x02 \x01(\tR\x06twinId\x12\x16\n\x06hostId\x18\x03 \x01(\tR\x06hostId\"\xbd\x01\n\x12\x44\x65leteInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.DeleteInputRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x13\x44\x65leteInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.DeleteInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x97\x02\n\x12\x43reateInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.CreateInputRequest.ArgumentsR\x04\x61rgs\x12@\n\x07payload\x18\x03 \x01(\x0b\x32&.iotics.api.CreateInputRequest.PayloadR\x07payload\x1a\x19\n\x07Payload\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xc1\x01\n\x13\x43reateInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.CreateInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xf2\x02\n\x12UpdateInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.UpdateInputRequest.ArgumentsR\x04\x61rgs\x12@\n\x07payload\x18\x03 \x01(\x0b\x32&.iotics.api.UpdateInputRequest.PayloadR\x07payload\x1aq\n\x07Payload\x12*\n\x06values\x18\x01 \x01(\x0b\x32\x12.iotics.api.ValuesR\x06values\x12:\n\nproperties\x18\x02 \x01(\x0b\x32\x1a.iotics.api.PropertyUpdateR\nproperties\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x13UpdateInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.UpdateInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x14\x44\x65scribeInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12>\n\x04\x61rgs\x18\x02 \x01(\x0b\x32*.iotics.api.DescribeInputRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xfa\x02\n\x15\x44\x65scribeInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x43\n\x07payload\x18\x02 \x01(\x0b\x32).iotics.api.DescribeInputResponse.PayloadR\x07payload\x1am\n\nMetaResult\x12)\n\x06values\x18\x01 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x34\n\nproperties\x18\x02 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x1a~\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\x12\x44\n\x06result\x18\x02 \x01(\x0b\x32,.iotics.api.DescribeInputResponse.MetaResultR\x06result\"\x86\x01\n\x13UpsertInputWithMeta\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x06values\x18\x02 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x34\n\nproperties\x18\x03 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\"r\n\x0cInputMessage\x12:\n\noccurredAt\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x12\n\x04mime\x18\x02 \x01(\tR\x04mime\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\xcd\x01\n\x1aReceiveInputMessageRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x44\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x30.iotics.api.ReceiveInputMessageRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x85\x02\n\x1bReceiveInputMessageResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12I\n\x07payload\x18\x02 \x01(\x0b\x32/.iotics.api.ReceiveInputMessageResponse.PayloadR\x07payload\x1al\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\x12\x32\n\x07message\x18\x02 \x01(\x0b\x32\x18.iotics.api.InputMessageR\x07message2\xc5\x03\n\x08InputAPI\x12P\n\x0b\x44\x65leteInput\x12\x1e.iotics.api.DeleteInputRequest\x1a\x1f.iotics.api.DeleteInputResponse\"\x00\x12V\n\rDescribeInput\x12 .iotics.api.DescribeInputRequest\x1a!.iotics.api.DescribeInputResponse\"\x00\x12k\n\x14ReceiveInputMessages\x12&.iotics.api.ReceiveInputMessageRequest\x1a\'.iotics.api.ReceiveInputMessageResponse\"\x00\x30\x01\x12P\n\x0b\x43reateInput\x12\x1e.iotics.api.CreateInputRequest\x1a\x1f.iotics.api.CreateInputResponse\"\x00\x12P\n\x0bUpdateInput\x12\x1e.iotics.api.UpdateInputRequest\x1a\x1f.iotics.api.UpdateInputResponse\"\x00\x42~\n\x0e\x63om.iotics.apiB\nInputProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.input_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\nInputProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_INPUTID']._serialized_start=96
  _globals['_INPUTID']._serialized_end=169
  _globals['_DELETEINPUTREQUEST']._serialized_start=172
  _globals['_DELETEINPUTREQUEST']._serialized_end=361
  _globals['_DELETEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_DELETEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_DELETEINPUTRESPONSE']._serialized_start=364
  _globals['_DELETEINPUTRESPONSE']._serialized_end=557
  _globals['_DELETEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_DELETEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_CREATEINPUTREQUEST']._serialized_start=560
  _globals['_CREATEINPUTREQUEST']._serialized_end=839
  _globals['_CREATEINPUTREQUEST_PAYLOAD']._serialized_start=757
  _globals['_CREATEINPUTREQUEST_PAYLOAD']._serialized_end=782
  _globals['_CREATEINPUTREQUEST_ARGUMENTS']._serialized_start=784
  _globals['_CREATEINPUTREQUEST_ARGUMENTS']._serialized_end=839
  _globals['_CREATEINPUTRESPONSE']._serialized_start=842
  _globals['_CREATEINPUTRESPONSE']._serialized_end=1035
  _globals['_CREATEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_CREATEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_UPDATEINPUTREQUEST']._serialized_start=1038
  _globals['_UPDATEINPUTREQUEST']._serialized_end=1408
  _globals['_UPDATEINPUTREQUEST_PAYLOAD']._serialized_start=1235
  _globals['_UPDATEINPUTREQUEST_PAYLOAD']._serialized_end=1348
  _globals['_UPDATEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_UPDATEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_UPDATEINPUTRESPONSE']._serialized_start=1411
  _globals['_UPDATEINPUTRESPONSE']._serialized_end=1604
  _globals['_UPDATEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_UPDATEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_DESCRIBEINPUTREQUEST']._serialized_start=1607
  _globals['_DESCRIBEINPUTREQUEST']._serialized_end=1800
  _globals['_DESCRIBEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_DESCRIBEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_DESCRIBEINPUTRESPONSE']._serialized_start=1803
  _globals['_DESCRIBEINPUTRESPONSE']._serialized_end=2181
  _globals['_DESCRIBEINPUTRESPONSE_METARESULT']._serialized_start=1944
  _globals['_DESCRIBEINPUTRESPONSE_METARESULT']._serialized_end=2053
  _globals['_DESCRIBEINPUTRESPONSE_PAYLOAD']._serialized_start=2055
  _globals['_DESCRIBEINPUTRESPONSE_PAYLOAD']._serialized_end=2181
  _globals['_UPSERTINPUTWITHMETA']._serialized_start=2184
  _globals['_UPSERTINPUTWITHMETA']._serialized_end=2318
  _globals['_INPUTMESSAGE']._serialized_start=2320
  _globals['_INPUTMESSAGE']._serialized_end=2434
  _globals['_RECEIVEINPUTMESSAGEREQUEST']._serialized_start=2437
  _globals['_RECEIVEINPUTMESSAGEREQUEST']._serialized_end=2642
  _globals['_RECEIVEINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_RECEIVEINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_RECEIVEINPUTMESSAGERESPONSE']._serialized_start=2645
  _globals['_RECEIVEINPUTMESSAGERESPONSE']._serialized_end=2906
  _globals['_RECEIVEINPUTMESSAGERESPONSE_PAYLOAD']._serialized_start=2798
  _globals['_RECEIVEINPUTMESSAGERESPONSE_PAYLOAD']._serialized_end=2906
  _globals['_INPUTAPI']._serialized_start=2909
  _globals['_INPUTAPI']._serialized_end=3362
# @@protoc_insertion_point(module_scope)
