# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/twin.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/twin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2
from iotics.api import feed_pb2 as iotics_dot_api_dot_feed__pb2
from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15iotics/api/twin.proto\x12\niotics.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17iotics/api/common.proto\x1a\x15iotics/api/feed.proto\x1a\x16iotics/api/input.proto\"m\n\x13ListAllTwinsRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05range\x18\x14 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\"\xb9\x03\n\x14ListAllTwinsResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.ListAllTwinsResponse.PayloadR\x07payload\x1a\xde\x01\n\x0bTwinDetails\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x33\n\x08location\x18\x03 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x34\n\nproperties\x18\x05 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1aM\n\x07Payload\x12\x42\n\x05twins\x18\x01 \x03(\x0b\x32,.iotics.api.ListAllTwinsResponse.TwinDetailsR\x05twins\"\x9e\x01\n\x11\x43reateTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x07payload\x18\x02 \x01(\x0b\x32%.iotics.api.CreateTwinRequest.PayloadR\x07payload\x1a\x19\n\x07Payload\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xbc\x01\n\x12\x43reateTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.CreateTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xb8\x01\n\x11\x44\x65leteTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.DeleteTwinRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xbc\x01\n\x12\x44\x65leteTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.DeleteTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xbc\x01\n\x13\x44\x65scribeTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12=\n\x04\x61rgs\x18\x03 \x01(\x0b\x32).iotics.api.DescribeTwinRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"T\n\x08\x46\x65\x65\x64Meta\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\x12\x1c\n\tstoreLast\x18\x03 \x01(\x08R\tstoreLast\":\n\tInputMeta\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x94\x04\n\x14\x44\x65scribeTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.DescribeTwinResponse.PayloadR\x07payload\x1a\x8c\x02\n\nMetaResult\x12\x33\n\x08location\x18\x01 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12*\n\x05\x66\x65\x65\x64s\x18\x04 \x03(\x0b\x32\x14.iotics.api.FeedMetaR\x05\x66\x65\x65\x64s\x12-\n\x06inputs\x18\x05 \x03(\x0b\x32\x15.iotics.api.InputMetaR\x06inputs\x12\x34\n\nproperties\x18\x06 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1az\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x43\n\x06result\x18\x02 \x01(\x0b\x32+.iotics.api.DescribeTwinResponse.MetaResultR\x06result\"H\n\x11GeoLocationUpdate\x12\x33\n\x08location\x18\x01 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\"\xfc\x02\n\x11UpdateTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.UpdateTwinRequest.ArgumentsR\x04\x61rgs\x12?\n\x07payload\x18\x03 \x01(\x0b\x32%.iotics.api.UpdateTwinRequest.PayloadR\x07payload\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x1a\x80\x01\n\x07Payload\x12:\n\nproperties\x18\x03 \x01(\x0b\x32\x1a.iotics.api.PropertyUpdateR\nproperties\x12\x39\n\x08location\x18\x06 \x01(\x0b\x32\x1d.iotics.api.GeoLocationUpdateR\x08location\"\xbc\x01\n\x12UpdateTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.UpdateTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\x95\x03\n\x11UpsertTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x07payload\x18\x02 \x01(\x0b\x32%.iotics.api.UpsertTwinRequest.PayloadR\x07payload\x1a\x8f\x02\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x34\n\nproperties\x18\x05 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x33\n\x08location\x18\x06 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x34\n\x05\x66\x65\x65\x64s\x18\x07 \x03(\x0b\x32\x1e.iotics.api.UpsertFeedWithMetaR\x05\x66\x65\x65\x64s\x12\x37\n\x06inputs\x18\x08 \x03(\x0b\x32\x1f.iotics.api.UpsertInputWithMetaR\x06inputs\"\xbc\x01\n\x12UpsertTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.UpsertTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId2\xef\x03\n\x07TwinAPI\x12M\n\nCreateTwin\x12\x1d.iotics.api.CreateTwinRequest\x1a\x1e.iotics.api.CreateTwinResponse\"\x00\x12M\n\nUpsertTwin\x12\x1d.iotics.api.UpsertTwinRequest\x1a\x1e.iotics.api.UpsertTwinResponse\"\x00\x12M\n\nDeleteTwin\x12\x1d.iotics.api.DeleteTwinRequest\x1a\x1e.iotics.api.DeleteTwinResponse\"\x00\x12M\n\nUpdateTwin\x12\x1d.iotics.api.UpdateTwinRequest\x1a\x1e.iotics.api.UpdateTwinResponse\"\x00\x12S\n\x0c\x44\x65scribeTwin\x12\x1f.iotics.api.DescribeTwinRequest\x1a .iotics.api.DescribeTwinResponse\"\x00\x12S\n\x0cListAllTwins\x12\x1f.iotics.api.ListAllTwinsRequest\x1a .iotics.api.ListAllTwinsResponse\"\x00\x42}\n\x0e\x63om.iotics.apiB\tTwinProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.twin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\tTwinProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_LISTALLTWINSREQUEST']._serialized_start=142
  _globals['_LISTALLTWINSREQUEST']._serialized_end=251
  _globals['_LISTALLTWINSRESPONSE']._serialized_start=254
  _globals['_LISTALLTWINSRESPONSE']._serialized_end=695
  _globals['_LISTALLTWINSRESPONSE_TWINDETAILS']._serialized_start=394
  _globals['_LISTALLTWINSRESPONSE_TWINDETAILS']._serialized_end=616
  _globals['_LISTALLTWINSRESPONSE_PAYLOAD']._serialized_start=618
  _globals['_LISTALLTWINSRESPONSE_PAYLOAD']._serialized_end=695
  _globals['_CREATETWINREQUEST']._serialized_start=698
  _globals['_CREATETWINREQUEST']._serialized_end=856
  _globals['_CREATETWINREQUEST_PAYLOAD']._serialized_start=831
  _globals['_CREATETWINREQUEST_PAYLOAD']._serialized_end=856
  _globals['_CREATETWINRESPONSE']._serialized_start=859
  _globals['_CREATETWINRESPONSE']._serialized_end=1047
  _globals['_CREATETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_CREATETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_DELETETWINREQUEST']._serialized_start=1050
  _globals['_DELETETWINREQUEST']._serialized_end=1234
  _globals['_DELETETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_DELETETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_DELETETWINRESPONSE']._serialized_start=1237
  _globals['_DELETETWINRESPONSE']._serialized_end=1425
  _globals['_DELETETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_DELETETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_DESCRIBETWINREQUEST']._serialized_start=1428
  _globals['_DESCRIBETWINREQUEST']._serialized_end=1616
  _globals['_DESCRIBETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_DESCRIBETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_FEEDMETA']._serialized_start=1618
  _globals['_FEEDMETA']._serialized_end=1702
  _globals['_INPUTMETA']._serialized_start=1704
  _globals['_INPUTMETA']._serialized_end=1762
  _globals['_DESCRIBETWINRESPONSE']._serialized_start=1765
  _globals['_DESCRIBETWINRESPONSE']._serialized_end=2297
  _globals['_DESCRIBETWINRESPONSE_METARESULT']._serialized_start=1905
  _globals['_DESCRIBETWINRESPONSE_METARESULT']._serialized_end=2173
  _globals['_DESCRIBETWINRESPONSE_PAYLOAD']._serialized_start=2175
  _globals['_DESCRIBETWINRESPONSE_PAYLOAD']._serialized_end=2297
  _globals['_GEOLOCATIONUPDATE']._serialized_start=2299
  _globals['_GEOLOCATIONUPDATE']._serialized_end=2371
  _globals['_UPDATETWINREQUEST']._serialized_start=2374
  _globals['_UPDATETWINREQUEST']._serialized_end=2754
  _globals['_UPDATETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_UPDATETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_UPDATETWINREQUEST_PAYLOAD']._serialized_start=2626
  _globals['_UPDATETWINREQUEST_PAYLOAD']._serialized_end=2754
  _globals['_UPDATETWINRESPONSE']._serialized_start=2757
  _globals['_UPDATETWINRESPONSE']._serialized_end=2945
  _globals['_UPDATETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_UPDATETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_UPSERTTWINREQUEST']._serialized_start=2948
  _globals['_UPSERTTWINREQUEST']._serialized_end=3353
  _globals['_UPSERTTWINREQUEST_PAYLOAD']._serialized_start=3082
  _globals['_UPSERTTWINREQUEST_PAYLOAD']._serialized_end=3353
  _globals['_UPSERTTWINRESPONSE']._serialized_start=3356
  _globals['_UPSERTTWINRESPONSE']._serialized_end=3544
  _globals['_UPSERTTWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_UPSERTTWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_TWINAPI']._serialized_start=3547
  _globals['_TWINAPI']._serialized_end=4042
# @@protoc_insertion_point(module_scope)
